# remirepo spec file for php-pecl-yac
# with SCL compatibility, from:
#
# Fedora spec file for php-pecl-yac (previously php-yac)
#
# Copyright (c) 2013-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package  php-pecl-yac}

# use system library by default
%bcond_without fastlz

# run test suite by default
%bcond_without tests

%global gh_commit   7e5a9edfcfb6ad064c165a0b6abf8d11218fe4b5
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    laruence
%global gh_project  yac
#global gh_date     20150908
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name   yac
# after 20-json, 40-igbinary and 40-msgpack
%global ini_name    50-%{pecl_name}.ini
%if 0%{?gh_date:1}
%global sources     %{gh_project}-%{gh_commit}
%else
%global sources     %{pecl_name}-%{version}
%endif
%global _configure  ../%{sources}/configure

Summary:        Lockless user data cache
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        2.3.1
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
%if 0%{?gh_date:1}
Release:        0.15.%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{pecl_name}-%{version}-%{gh_short}.tar.gz
%else
Release:        7%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz
%endif

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json
BuildRequires:  %{?scl_prefix}php-pecl-msgpack-devel
BuildRequires:  %{?scl_prefix}php-pecl-igbinary-devel
%if %{with fastlz}
BuildRequires:  fastlz-devel
%endif

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa}
Requires:       %{?scl_prefix}php-igbinary%{?_isa}
Requires:       %{?scl_prefix}php-msgpack%{?_isa}

# Package have be renamed
Obsoletes:      %{?scl_prefix}php-%{pecl_name}               < %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
Yac (Yet Another Cache) is a shared memory user data cache for PHP.

It can be used to replace APC or local memcached.

Yac is lockless, that means, it is very fast, but there could be a
chance you will get a wrong data(depends on how many key slots are
allocated and how many keys are stored), so you'd better make sure
that your product is not very sensitive to that.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
%if 0%{?gh_date:1}
mv %{sources}/package.xml .
%endif

# Don't install (register) the tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
%if %{with fastlz}
sed -e '\:name="compressor/fastlz:d' -i ../package.xml
rm -r compressor/fastlz
%endif

# Check version as upstream often forget to update this
extver=$(sed -n '/#define PHP_YAC_VERSION/{s/.* "//;s/".*$//;p}' php_yac.h)
if test "x${extver}" != "x%{version}%{?prever}%{?gh_date:-dev}"; then
   : Error: Upstream YAC version is ${extver}, expecting %{version}%{?prever}%{?gh_date:-dev}.
   exit 1
fi
cd ..

# Drop in the bit of configuration
cat > %{ini_name} << 'EOF'
; Enable Yet Another Cache extension module
extension = %{pecl_name}.so

;yac.enable=1
;yac.enable_cli=0
;yac.debug=0
;yac.keys_memory_size=4M
;yac.values_memory_size=64M
;yac.compress_threshold=-1
;yac.serializer=php
EOF


mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

peclconf() {
%configure \
    --enable-json \
    --enable-msgpack \
    --enable-igbinary \
%if %{with fastlz}
    --with-system-fastlz \
%endif
    --with-php-config=$1
}

cd %{sources}
%{_bindir}/phpize

cd ../NTS
peclconf %{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
peclconf %{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Install the ZTS stuff
%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in README.md $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do [ -f %{sources}/$i ] &&  install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}
OPTS="-n"
[ -f %{php_extdir}/json.so     ] && OPTS="$OPTS -d extension=json.so"
[ -f %{php_extdir}/igbinary.so ] && OPTS="$OPTS -d extension=igbinary.so"
[ -f %{php_extdir}/msgpack.so  ] && OPTS="$OPTS -d extension=msgpack.so"

: Minimal load test for NTS extension
%{_bindir}/php $OPTS \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="$OPTS -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%else
: Upstream test suite disabled
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} $OPTS \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$OPTS -d extension=$PWD/../ZTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%else
: Upstream test suite disabled
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 2.3.1-7
- rebuild for PHP 8.3.0RC1

* Tue Jul 18 2023 Remi Collet <remi@remirepo.net> - 2.3.1-6
- build out of sources tree

* Mon Dec 20 2021 Remi Collet <remi@remirepo.net> - 2.3.1-5
- update to 2.3.1
- drop patch merged upstream

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 2.3.0-5
- rebuild for 8.1.0RC1

* Wed Aug  4 2021 Remi Collet <remi@remirepo.net> - 2.3.0-4
- add patch for test suite with 8.1.0beta2 from
  https://github.com/laruence/yac/pull/120

* Fri Apr 30 2021 Remi Collet <remi@remirepo.net> - 2.3.0-3
- F34 rebuild for https://github.com/remicollet/remirepo/issues/174

* Wed Jan  6 2021 Remi Collet <remi@remirepo.net> - 2.3.0-1
- update to 2.3.0

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 2.2.1-3
- rebuild for PHP 8.0.0RC1

* Wed Sep 23 2020 Remi Collet <remi@remirepo.net> - 2.2.1-2
- add patch for PHP 8 from
  https://github.com/laruence/yac/pull/115

* Fri May 15 2020 Remi Collet <remi@remirepo.net> - 2.2.1-1
- update to 2.2.1

* Tue Mar 31 2020 Remi Collet <remi@remirepo.net> - 2.2.0-1
- update to 2.2.0
- enable json, igbinary and msgpack serializers
- rename configuration file to 50-yac.ini to ensure proper load order

* Fri Mar 27 2020 Remi Collet <remi@remirepo.net> - 2.1.2-1
- update to 2.1.2

* Wed Mar 25 2020 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1

* Wed Mar 25 2020 Remi Collet <remi@remirepo.net> - 2.1.0-1
- update to 2.1.0
- add missing file from git repository and open
  https://github.com/laruence/yac/pull/104
- add upstream patch to fix 32-bit builds reported as
  https://github.com/laruence/yac/issues/105

* Thu Mar 19 2020 Remi Collet <remi@remirepo.net> - 2.0.4-1
- update to 2.0.4

* Mon Jan  6 2020 Remi Collet <remi@remirepo.net> - 2.0.3-1
- update to 2.0.3

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.2-6
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.0.2-5
- rebuild for 7.4.0beta1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.0.2-4
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.0.2-3
- rebuild for 7.3.0alpha4 new ABI

* Thu Jun 28 2018 Remi Collet <remi@remirepo.net> - 2.0.2-2
- add patch for PHP 7.3 from
  https://github.com/laruence/yac/pull/89

* Tue Aug  1 2017 Remi Collet <remi@remirepo.net> - 2.0.2-1
- Update to 2.0.2

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.1-4
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-2
- rebuild for PHP 7.1 new API version

* Sat Jul  2 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-1
- update to 2.0.1 (php 7)
- sources from pecl

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-2
- adapt for F24

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- update to 2.0.0 (php 7)

* Tue Oct 13 2015 Remi Collet <remi@fedoraproject.org> - 0.9.3-0.6.20150908gita406e46
- rebuild for PHP 7.0.0RC5 new API version
- new snapshot

* Fri Sep 18 2015 Remi Collet <remi@fedoraproject.org> - 0.9.3-0.5.20150717git74fa8e2
- F23 rebuild with rh_layout

* Wed Jul 22 2015 Remi Collet <remi@fedoraproject.org> - 0.9.3-0.4.20150717git74fa8e2
- rebuild against php 7.0.0beta2

* Wed Jul  8 2015 Remi Collet <remi@fedoraproject.org> - 0.9.3-0.3.20150701git85f6e35
- rebuild against php 7.0.0beta1

* Wed Jun 24 2015 Remi Collet <remi@fedoraproject.org> - 0.9.3-0.2.20150616git1d26cd4
- rebuild for "rh_layout" (php70)

* Tue Jun 16 2015 Remi Collet <remi@fedoraproject.org> - 0.9.3-0.1.20150616git1d26cd4
- update to 0.9.3-dev for PHP 7
- sources from github

* Sun Mar  1 2015 Remi Collet <remi@fedoraproject.org> - 0.9.2-2
- drop runtime dependency on pear, new scriplets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-1.1
- Fedora 21 SCL mass rebuild

* Sat Oct 25 2014 Remi Collet <remi@fedoraproject.org> - 0.9.2-1
- Update to 0.9.2

* Sat Sep  6 2014 Remi Collet <remi@fedoraproject.org> - 0.9.1-3
- test build with system fastlz
- don't install the tests

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 0.9.1-2
- improve SCL build

* Fri Jul 25 2014 Remi Collet <remi@fedoraproject.org> - 0.9.1-1
- Update to 0.9.1 (beta)

* Thu Jul 24 2014 Remi Collet <remi@fedoraproject.org> - 0.9.0-1
- upstream move to pecl
- rename from php-yac to php-pecl-yac
- update to 0.9.0 (beta)

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-3
- add numerical prefix to extension configuration file (php 5.6)

* Tue Mar 25 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-2
- allow SCL build

* Sun Mar 16 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-1
- version 0.1.1

* Sat Mar 23 2013 Remi Collet <remi@fedoraproject.org> - 0.1.0-0.1.git57fe00d
- initial package, version 0.1.0 (experimental)

